@@ -1,5 +1,3 @@
-{-# LANGUAGE CPP #-}
-
 -- | @hspec@ and @tasty@ serve similar purposes; consider using one or the
 -- other.
 --
@@ -26,12 +24,11 @@ import qualified Test.Hspec as Hspec
 import qualified Test.Hspec.Core.Formatters as Hspec.Core.Formatters
 import qualified Test.Hspec.Core.Spec as Hspec.Core.Spec
 import qualified Test.Tasty as Tasty
-import Test.Tasty.Hspec.Compat
 import qualified Test.Tasty.Options as Tasty.Options
 import qualified Test.Tasty.Providers as Tasty.Providers
-import qualified Test.Tasty.QuickCheck as TQC
+import qualified Test.Tasty.QuickCheck as Tasty.QuickCheck
 import qualified Test.Tasty.Runners as Tasty.Runners
-import qualified Test.Tasty.SmallCheck as TSC
+import qualified Test.Tasty.SmallCheck as Tasty.SmallCheck
 
 -- $examples
 --
@@ -88,17 +85,17 @@ testSpecs spec = do
   -- Here we do as hspec does, which is pre-process a spec by focusing the whole thing, which is a no-op if
   -- anything inside is already focused, but otherwise focuses every item. Then, when creating a tasty test tree,
   -- we just toss the unfocused items.
-  trees <- runSpecM (focus spec)
+  (_configBuilder, trees) <- Hspec.Core.Spec.runSpecM (Hspec.focus spec)
   pure (mapMaybe specTreeToTestTree trees)
 
 specTreeToTestTree :: Hspec.Core.Spec.SpecTree () -> Maybe Tasty.TestTree
 specTreeToTestTree = \case
-  Node name trees -> pure (Tasty.testGroup name (mapMaybe specTreeToTestTree trees))
-  NodeWithCleanup cleanup trees -> do
-    tree <- specTreeToTestTree (Node "(unnamed)" trees)
-    pure (Tasty.Runners.WithResource (Tasty.Runners.ResourceSpec (pure ()) (twiddleCleanup cleanup)) (const tree))
-  Leaf item -> do
-    guard (itemIsFocused item)
+  Hspec.Core.Spec.Node name trees -> pure (Tasty.testGroup name (mapMaybe specTreeToTestTree trees))
+  Hspec.Core.Spec.NodeWithCleanup _loc cleanup trees -> do
+    tree <- specTreeToTestTree (Hspec.Core.Spec.Node "(unnamed)" trees)
+    pure (Tasty.Runners.WithResource (Tasty.Runners.ResourceSpec (pure ()) (const cleanup)) (const tree))
+  Hspec.Core.Spec.Leaf item -> do
+    guard (Hspec.Core.Spec.itemIsFocused item)
     pure (Tasty.Providers.singleTest (Hspec.Core.Spec.itemRequirement item) (Item item))
 
 newtype Item
@@ -107,13 +104,18 @@ newtype Item
 
 instance Tasty.Providers.IsTest Item where
   run opts (Item item) progress = do
-    qcArgs <- optionSetToQuickCheckArgs opts
+    (_, qcArgs) <- Tasty.QuickCheck.optionSetToArgs opts
+    -- optionSetToQuickCheckArgs :: Tasty.OptionSet -> IO QuickCheck.Args
+    -- optionSetToQuickCheckArgs opts =
+    --   snd <$> Tasty.QuickCheck.optionSetToArgs opts
     let params =
           Hspec.Core.Spec.Params
             { Hspec.Core.Spec.paramsQuickCheckArgs = qcArgs,
-              Hspec.Core.Spec.paramsSmallCheckDepth = optionSetToSmallCheckDepth opts
+              Hspec.Core.Spec.paramsSmallCheckDepth =
+                case Tasty.Options.lookupOption opts of
+                  Tasty.SmallCheck.SmallCheckDepth depth -> Just depth
             }
-    Hspec.Core.Spec.Result _ result <- itemExample item params ($ ()) progress'
+    Hspec.Core.Spec.Result _ result <- Hspec.Core.Spec.itemExample item params ($ ()) progress'
     pure
       ( case result of
           Hspec.Core.Spec.Success -> Tasty.Providers.testPassed ""
@@ -147,11 +149,11 @@ instance Tasty.Providers.IsTest Item where
   testOptions =
     pure
       [ Tasty.Options.Option (Proxy :: Proxy TreatPendingAs),
-        Tasty.Options.Option (Proxy :: Proxy TQC.QuickCheckTests),
-        Tasty.Options.Option (Proxy :: Proxy TQC.QuickCheckReplay),
-        Tasty.Options.Option (Proxy :: Proxy TQC.QuickCheckMaxSize),
-        Tasty.Options.Option (Proxy :: Proxy TQC.QuickCheckMaxRatio),
-        Tasty.Options.Option (Proxy :: Proxy TSC.SmallCheckDepth)
+        Tasty.Options.Option (Proxy :: Proxy Tasty.QuickCheck.QuickCheckTests),
+        Tasty.Options.Option (Proxy :: Proxy Tasty.QuickCheck.QuickCheckReplay),
+        Tasty.Options.Option (Proxy :: Proxy Tasty.QuickCheck.QuickCheckMaxSize),
+        Tasty.Options.Option (Proxy :: Proxy Tasty.QuickCheck.QuickCheckMaxRatio),
+        Tasty.Options.Option (Proxy :: Proxy Tasty.SmallCheck.SmallCheckDepth)
       ]
 
 -- | How to treat @hspec@ pending tests.
@@ -180,7 +182,5 @@ instance Tasty.Options.IsOption TreatPendingAs where
   optionHelp =
     pure "How to treat pending hspec tests ('failure' or 'success')"
 
-#if MIN_VERSION_tasty(1,3,0)
   showDefaultValue _ =
     Just "failure"
-#endif
